package nce.editor;

import java.util.HashMap;
import java.util.Map;

import nce.editor.prefs.ColorsPreferencePage;

import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.PreferenceConverter;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.RGB;


public class ColorManager extends ColorCache {

	private Map<TokenType, String> typeToPropertyMap;

	private IPreferenceStore fPreferenceStore;

	private Map<String, Color> fColorMap;
	
	public ColorManager(IPreferenceStore preferenceStore) {
		fColorMap = new HashMap<String, Color>();
		this.fPreferenceStore = preferenceStore;
		initTypeToPropertyMap();
	}


	public Color getColor(String propertyName) {
		
		RGB prefColor = PreferenceConverter.getColor(fPreferenceStore, propertyName);
		Color color = null;
		if (fColorMap.containsKey(propertyName) && fColorMap.get(propertyName).getRGB().equals(prefColor)) {
			color = fColorMap.get(propertyName);
		} else {
			color = getColor(prefColor);
			fColorMap.put(propertyName, color);
		}
		
		return color;
	}
	
	/** 
	 * Converts the ColoringPartitionScanner's type name to the appropriate preference 
	 * store color name.
	 * @param tokenType
	 * @return String
	 */
	public String getPropertyForType(TokenType tokenType)
	{
		String kind = (String) typeToPropertyMap.get(tokenType);
		if(kind == null) {
			return "";
		}
		return kind; 
	}
	
	protected void initTypeToPropertyMap() {
		
		typeToPropertyMap = new HashMap<TokenType, String>();
		typeToPropertyMap.put(TokenType.COMMENT1, ColorsPreferencePage.COMMENT1_COLOR);
		typeToPropertyMap.put(TokenType.COMMENT2, ColorsPreferencePage.COMMENT2_COLOR);
		typeToPropertyMap.put(TokenType.COMMENT3, ColorsPreferencePage.COMMENT3_COLOR);
		typeToPropertyMap.put(TokenType.COMMENT4, ColorsPreferencePage.COMMENT4_COLOR);
		typeToPropertyMap.put(TokenType.LITERAL1, ColorsPreferencePage.LITERAL1_COLOR);
		typeToPropertyMap.put(TokenType.LITERAL2, ColorsPreferencePage.LITERAL2_COLOR);
		typeToPropertyMap.put(TokenType.LITERAL3, ColorsPreferencePage.LITERAL3_COLOR);
		typeToPropertyMap.put(TokenType.LITERAL4, ColorsPreferencePage.LITERAL4_COLOR);
		typeToPropertyMap.put(TokenType.LABEL, ColorsPreferencePage.LABEL_COLOR);
		typeToPropertyMap.put(TokenType.KEYWORD1, ColorsPreferencePage.KEYWORD1_COLOR);
		typeToPropertyMap.put(TokenType.KEYWORD2, ColorsPreferencePage.KEYWORD2_COLOR);
		typeToPropertyMap.put(TokenType.KEYWORD3, ColorsPreferencePage.KEYWORD3_COLOR);
		typeToPropertyMap.put(TokenType.KEYWORD4, ColorsPreferencePage.KEYWORD4_COLOR);
		typeToPropertyMap.put(TokenType.FUNCTION, ColorsPreferencePage.FUNCTION_COLOR);
		typeToPropertyMap.put(TokenType.MARKUP, ColorsPreferencePage.MARKUP_COLOR);
		typeToPropertyMap.put(TokenType.OPERATOR, ColorsPreferencePage.OPERATOR_COLOR);
		typeToPropertyMap.put(TokenType.DIGIT, ColorsPreferencePage.DIGIT_COLOR);
		typeToPropertyMap.put(TokenType.INVALID, ColorsPreferencePage.INVALID_COLOR);
		typeToPropertyMap.put(TokenType.NULL, ColorsPreferencePage.NULL_COLOR);
	}
		
	public int getStyleFor(String colorName) {
		
		String boldSuffix = ColorsPreferencePage.BOLD_SUFFIX;
		if(colorName == null) colorName = ColorsPreferencePage.NULL_COLOR;
		String boldName = colorName + boldSuffix;
		boolean isBold = fPreferenceStore.getBoolean(boldName);
		
		return isBold ? SWT.BOLD : SWT.NORMAL;
	}
	
}
